@@ -3,12 +3,12 @@
 
 __author__ = """MIT Data To AI Lab"""
 __email__ = 'dailabmit@gmail.com'
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 import logging
 import os
 
-from cardea.cardea import Cardea
+from cardea.core import Cardea
 
 logging.getLogger('cardea').addHandler(logging.NullHandler())
 
